ClueSquareTextField constructor

const ClueSquareTextField({
  1. Key? key,
  2. double width = 250,
  3. bool autofocus = false,
  4. String? initialValue,
  5. TextEditingController? controller,
  6. void onChanged(
    1. String value
    )?,
  7. void onEditingComplete()?,
  8. String? hintText,
  9. String? errorText,
  10. int errorMaxLines = 1,
  11. Widget? suffixIcon,
  12. List<TextInputFormatter>? inputFormatters,
  13. bool obscureText = false,
  14. int maxLength = 30,
  15. bool enabled = true,
  16. bool showCounterText = false,
  17. bool useErrorText = false,
})

Creates a ClueSquareTextField.

width specifies the width of the text field. autofocus determines if the text field should autofocus. initialValue is the initial value of the text field. controller is the controller for the text field. onChanged is the callback function when the text changes. onEditingComplete is the callback function when editing is complete. hintText is the hint text displayed in the text field. errorText is the error text displayed below the text field. errorMaxLines specifies the maximum number of lines for the error text. suffixIcon is the icon displayed at the end of the text field. inputFormatters specifies the input formatters for the text field. obscureText determines if the text should be obscured. maxLength specifies the maximum length of the text. enabled determines if the text field is enabled. showCounterText determines if the counter text should be displayed. useErrorText determines if the error text should be used.

Implementation

const ClueSquareTextField({
  super.key,
  this.width = 250,
  this.autofocus = false,
  this.initialValue,
  this.controller,
  this.onChanged,
  this.onEditingComplete,
  this.hintText,
  this.errorText,
  this.errorMaxLines = 1,
  this.suffixIcon,
  this.inputFormatters,
  this.obscureText = false,
  this.maxLength = 30,
  this.enabled = true,
  this.showCounterText = false,
  this.useErrorText = false,
});